/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2016-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

import { SGraphItem } from "@persagy-web/graph/lib";
import { STextItem } from "@persagy-web/graph";
import { SColor } from "@persagy-web/draw/lib";
import { SIconTextItem } from "./SIconTextItem";
import { svgTobase64 } from "../utils/svgTobase64";

/**
 * 编辑基础设备类
 *
 * @author 韩耀龙 <han_yao_long@163.com>
 */
export class SEquipItem extends SIconTextItem {
    /** 图例节点 id */
    nodeId: string | null = null;

    /** 信息点存储 */
    _infoPointList: any[] = [];
    set infoPointList(val) {
        this._infoPointList = val;
    } // set infoPointList()
    get infoPointList(): any[] {
        return this._infoPointList;
    } // get infoPointList()

    /** 图得url */
    _url: string = "";
    set url(val) {
        this._url = val;
        this.initUrl();
    } // set url()
    get url(): string {
        return this._url;
    } // get url()

    //  设备附加数据
    anotherMsg: string = "";

    /**
     * 构造函数
     *
     * @param parent    指向父对象
     * @param data      数据
     */
    constructor(parent: SGraphItem | null) {
        super(parent);
        this.showSelect = false;
    } // Constructor

    /**
     * 初始化 url;
     *
     */
    initUrl() {
        svgTobase64(this.url)
            .then(res => {
                // @ts-ignore
                this.img.url = res ? res : "";
            })
            .catch(res => {
                this.img.url = res;
            });
    }

    /**
     * 根据选中状态增加 textItem
     *
     * @params obj	textItem 文本信息
     * @params index 文本索引
     */
    setTextItem(val: any, index: number): void {
            let item = new STextItem(this);
            item.data = val;
            item.text = val.name;
            if (val.pos) {
                item.moveTo(val.pos.x, val.pos.y);
            } else {
                item.moveTo(
                    this.img.width * 0.5,
                    -(this.font.size * 1.25 * 0.5) + index * 10
                );
            }

            item.font.size = val.font ? val.font : 12;
            item.isTransform = false;
            item.showSelect = false;
            item.color = val.color
                ? new SColor(val.color)
                : new SColor("#000000");
            this.textItemList.push(item);
    }
}
